@@ -2,13 +2,18 @@
 
 from __future__ import annotations
 
+import asyncio
+from collections.abc import Iterable
 from datetime import datetime, timedelta
 import logging
 from typing import Any
 
-from gcal_sync.api import GoogleCalendarService, ListEventsRequest
+from gcal_sync.api import GoogleCalendarService, ListEventsRequest, SyncEventsRequest
 from gcal_sync.exceptions import ApiException
-from gcal_sync.model import DateOrDatetime, Event
+from gcal_sync.model import AccessRole, DateOrDatetime, Event
+from gcal_sync.store import ScopedCalendarStore
+from gcal_sync.sync import CalendarEventSyncManager
+from gcal_sync.timeline import Timeline
 import voluptuous as vol
 
 from homeassistant.components.calendar import (
@@ -34,12 +39,12 @@ from homeassistant.helpers.update_coordinator import (
     DataUpdateCoordinator,
     UpdateFailed,
 )
+from homeassistant.util import dt as dt_util
 
 from . import (
     CONF_IGNORE_AVAILABILITY,
     CONF_SEARCH,
     CONF_TRACK,
-    DATA_SERVICE,
     DEFAULT_CONF_OFFSET,
     DOMAIN,
     YAML_DEVICES,
@@ -49,6 +54,8 @@ from . import (
 )
 from .api import get_feature_access
 from .const import (
+    DATA_SERVICE,
+    DATA_STORE,
     EVENT_DESCRIPTION,
     EVENT_END_DATE,
     EVENT_END_DATETIME,
@@ -66,6 +73,10 @@ _LOGGER = logging.getLogger(__name__)
 
 MIN_TIME_BETWEEN_UPDATES = timedelta(minutes=15)
 
+# Avoid syncing super old data on initial syncs. Note that old but active
+# recurring events are still included.
+SYNC_EVENT_MIN_TIME = timedelta(days=-90)
+
 # Events have a transparency that determine whether or not they block time on calendar.
 # When an event is opaque, it means "Show me as busy" which is the default.  Events that
 # are not opaque are ignored by default.
@@ -115,6 +126,7 @@ async def async_setup_entry(
 ) -> None:
     """Set up the google calendar platform."""
     calendar_service = hass.data[DOMAIN][config_entry.entry_id][DATA_SERVICE]
+    store = hass.data[DOMAIN][config_entry.entry_id][DATA_STORE]
     try:
         result = await calendar_service.async_list_calendars()
     except ApiException as err:
@@ -185,13 +197,36 @@ async def async_setup_entry(
                     entity_registry.async_remove(
                         entity_entry.entity_id,
                     )
-            coordinator = CalendarUpdateCoordinator(
-                hass,
-                calendar_service,
-                data[CONF_NAME],
-                calendar_id,
-                data.get(CONF_SEARCH),
-            )
+            coordinator: CalendarSyncUpdateCoordinator | CalendarQueryUpdateCoordinator
+            # Prefer calendar sync down of resources when possible. However, sync does not work
+            # for search. Also free-busy calendars denormalize recurring events as individual
+            # events which is not efficient for sync
+            if (
+                search := data.get(CONF_SEARCH)
+                or calendar_item.access_role == AccessRole.FREE_BUSY_READER
+            ):
+                coordinator = CalendarQueryUpdateCoordinator(
+                    hass,
+                    calendar_service,
+                    data[CONF_NAME],
+                    calendar_id,
+                    search,
+                )
+            else:
+                request_template = SyncEventsRequest(
+                    calendar_id=calendar_id,
+                    start_time=dt_util.now() + SYNC_EVENT_MIN_TIME,
+                )
+                sync = CalendarEventSyncManager(
+                    calendar_service,
+                    store=ScopedCalendarStore(store, unique_id or entity_name),
+                    request_template=request_template,
+                )
+                coordinator = CalendarSyncUpdateCoordinator(
+                    hass,
+                    sync,
+                    data[CONF_NAME],
+                )
             entities.append(
                 GoogleCalendarEntity(
                     coordinator,
@@ -203,7 +238,7 @@ async def async_setup_entry(
                 )
             )
 
-    async_add_entities(entities, True)
+    async_add_entities(entities)
 
     if calendars and new_calendars:
 
@@ -223,8 +258,62 @@ async def async_setup_entry(
         )
 
 
-class CalendarUpdateCoordinator(DataUpdateCoordinator):
-    """Coordinator for calendar RPC calls."""
+class CalendarSyncUpdateCoordinator(DataUpdateCoordinator[Timeline]):
+    """Coordinator for calendar RPC calls that use an efficient sync."""
+
+    def __init__(
+        self,
+        hass: HomeAssistant,
+        sync: CalendarEventSyncManager,
+        name: str,
+    ) -> None:
+        """Create the CalendarSyncUpdateCoordinator."""
+        super().__init__(
+            hass,
+            _LOGGER,
+            name=name,
+            update_interval=MIN_TIME_BETWEEN_UPDATES,
+        )
+        self.sync = sync
+
+    async def _async_update_data(self) -> Timeline:
+        """Fetch data from API endpoint."""
+        try:
+            await self.sync.run()
+        except ApiException as err:
+            raise UpdateFailed(f"Error communicating with API: {err}") from err
+
+        return await self.sync.store_service.async_get_timeline(
+            dt_util.DEFAULT_TIME_ZONE
+        )
+
+    async def async_get_events(
+        self, start_date: datetime, end_date: datetime
+    ) -> Iterable[Event]:
+        """Get all events in a specific time frame."""
+        if not self.data:
+            raise HomeAssistantError(
+                "Unable to get events: Sync from server has not completed"
+            )
+        return self.data.overlapping(
+            dt_util.as_local(start_date),
+            dt_util.as_local(end_date),
+        )
+
+    @property
+    def upcoming(self) -> Iterable[Event] | None:
+        """Return upcoming events if any."""
+        if self.data:
+            return self.data.active_after(dt_util.now())
+        return None
+
+
+class CalendarQueryUpdateCoordinator(DataUpdateCoordinator[list[Event]]):
+    """Coordinator for calendar RPC calls.
+
+    This sends a polling RPC, not using sync, as a workaround
+    for limitations in the calendar API for supporting search.
+    """
 
     def __init__(
         self,
@@ -234,7 +323,7 @@ class CalendarUpdateCoordinator(DataUpdateCoordinator):
         calendar_id: str,
         search: str | None,
     ) -> None:
-        """Create the Calendar event device."""
+        """Create the CalendarQueryUpdateCoordinator."""
         super().__init__(
             hass,
             _LOGGER,
@@ -247,7 +336,7 @@ class CalendarUpdateCoordinator(DataUpdateCoordinator):
 
     async def async_get_events(
         self, start_date: datetime, end_date: datetime
-    ) -> list[Event]:
+    ) -> Iterable[Event]:
         """Get all events in a specific time frame."""
         request = ListEventsRequest(
             calendar_id=self.calendar_id,
@@ -274,6 +363,11 @@ class CalendarUpdateCoordinator(DataUpdateCoordinator):
             raise UpdateFailed(f"Error communicating with API: {err}") from err
         return result.items
 
+    @property
+    def upcoming(self) -> Iterable[Event] | None:
+        """Return the next upcoming event if any."""
+        return self.data
+
 
 class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
     """A calendar event entity."""
@@ -282,7 +376,7 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
 
     def __init__(
         self,
-        coordinator: CalendarUpdateCoordinator,
+        coordinator: CalendarSyncUpdateCoordinator | CalendarQueryUpdateCoordinator,
         calendar_id: str,
         data: dict[str, Any],
         entity_id: str,
@@ -341,10 +435,15 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
     async def async_added_to_hass(self) -> None:
         """When entity is added to hass."""
         await super().async_added_to_hass()
+
         # We do not ask for an update with async_add_entities()
-        # because it will update disabled entities
-        await self.coordinator.async_request_refresh()
-        self._apply_coordinator_update()
+        # because it will update disabled entities. This is started as a
+        # task to let if sync in the background without blocking startup
+        async def refresh() -> None:
+            await self.coordinator.async_request_refresh()
+            self._apply_coordinator_update()
+
+        asyncio.create_task(refresh())
 
     async def async_get_events(
         self, hass: HomeAssistant, start_date: datetime, end_date: datetime
@@ -358,12 +457,19 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
 
     def _apply_coordinator_update(self) -> None:
         """Copy state from the coordinator to this entity."""
-        events = self.coordinator.data
-        self._event = _get_calendar_event(next(iter(events))) if events else None
-        if self._event:
+        if api_event := next(
+            filter(
+                self._event_filter,
+                self.coordinator.upcoming or [],
+            ),
+            None,
+        ):
+            self._event = _get_calendar_event(api_event)
             (self._event.summary, self._offset_value) = extract_offset(
                 self._event.summary, self._offset
             )
+        else:
+            self._event = None
 
     @callback
     def _handle_coordinator_update(self) -> None:
@@ -431,7 +537,7 @@ async def async_create_event(entity: GoogleCalendarEntity, call: ServiceCall) ->
         raise ValueError("Missing required fields to set start or end date/datetime")
 
     try:
-        await entity.coordinator.calendar_service.async_create_event(
+        await entity.coordinator.sync.api.async_create_event(
             entity.calendar_id,
             Event(
                 summary=call.data[EVENT_SUMMARY],
@@ -442,3 +548,4 @@ async def async_create_event(entity: GoogleCalendarEntity, call: ServiceCall) ->
         )
     except ApiException as err:
         raise HomeAssistantError(str(err)) from err
+    entity.async_write_ha_state()
