@@ -18,6 +18,7 @@ from homeassistant.components.media_player import (
     SERVICE_PLAY_MEDIA,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
@@ -37,8 +38,6 @@ from homeassistant.const import (
     SERVICE_TURN_ON,
     SERVICE_VOLUME_MUTE,
     SERVICE_VOLUME_SET,
-    STATE_OFF,
-    STATE_ON,
     STATE_UNAVAILABLE,
     STATE_UNKNOWN,
 )
@@ -104,6 +103,7 @@ class MediaPlayerGroup(MediaPlayerEntity):
     """Representation of a Media Group."""
 
     _attr_available: bool = False
+    _attr_should_poll = False
 
     def __init__(self, unique_id: str | None, name: str, entities: list[str]) -> None:
         """Initialize a Media Group entity."""
@@ -217,11 +217,6 @@ class MediaPlayerGroup(MediaPlayerEntity):
         """Flag supported features."""
         return self._supported_features
 
-    @property
-    def should_poll(self) -> bool:
-        """No polling needed for a media group."""
-        return False
-
     @property
     def extra_state_attributes(self) -> dict:
         """Return the state attributes for the media group."""
@@ -277,7 +272,7 @@ class MediaPlayerGroup(MediaPlayerEntity):
             context=self._context,
         )
 
-    async def async_media_seek(self, position: int) -> None:
+    async def async_media_seek(self, position: float) -> None:
         """Send seek command."""
         data = {
             ATTR_ENTITY_ID: self._features[KEY_SEEK],
@@ -408,13 +403,13 @@ class MediaPlayerGroup(MediaPlayerEntity):
             # Set as unknown if all members are unknown or unavailable
             self._state = None
         else:
-            off_values = (STATE_OFF, STATE_UNAVAILABLE, STATE_UNKNOWN)
+            off_values = {MediaPlayerState.OFF, STATE_UNAVAILABLE, STATE_UNKNOWN}
             if states.count(states[0]) == len(states):
                 self._state = states[0]
             elif any(state for state in states if state not in off_values):
-                self._state = STATE_ON
+                self._state = MediaPlayerState.ON
             else:
-                self._state = STATE_OFF
+                self._state = MediaPlayerState.OFF
 
         supported_features = 0
         if self._features[KEY_CLEAR_PLAYLIST]:
