@@ -3,35 +3,29 @@ from __future__ import annotations
 
 from collections.abc import Mapping
 from datetime import timedelta
-import logging
 from typing import Any
 
-import voluptuous as vol
-
 from homeassistant.components.sensor import (
-    PLATFORM_SCHEMA,
     SensorEntity,
     SensorEntityDescription,
     SensorStateClass,
 )
-from homeassistant.config_entries import SOURCE_IMPORT, ConfigEntry
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     ATTR_ATTRIBUTION,
     ATTR_LATITUDE,
     ATTR_LONGITUDE,
-    CONF_API_KEY,
     CONF_MODE,
     CONF_NAME,
-    CONF_UNIT_SYSTEM,
+    LENGTH_KILOMETERS,
+    LENGTH_MILES,
     TIME_MINUTES,
 )
 from homeassistant.core import HomeAssistant
-import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.device_registry import DeviceEntryType
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.start import async_at_start
-from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
 from . import HereTravelTimeDataUpdateCoordinator
@@ -43,84 +37,14 @@ from .const import (
     ATTR_DURATION_IN_TRAFFIC,
     ATTR_ORIGIN,
     ATTR_ORIGIN_NAME,
-    ATTR_ROUTE,
-    CONF_ARRIVAL,
-    CONF_DEPARTURE,
-    CONF_DESTINATION_ENTITY_ID,
-    CONF_DESTINATION_LATITUDE,
-    CONF_DESTINATION_LONGITUDE,
-    CONF_ORIGIN_ENTITY_ID,
-    CONF_ORIGIN_LATITUDE,
-    CONF_ORIGIN_LONGITUDE,
-    CONF_ROUTE_MODE,
-    CONF_TRAFFIC_MODE,
-    DEFAULT_NAME,
     DOMAIN,
     ICON_CAR,
     ICONS,
-    ROUTE_MODE_FASTEST,
-    ROUTE_MODES,
-    TRAVEL_MODE_BICYCLE,
-    TRAVEL_MODE_CAR,
-    TRAVEL_MODE_PEDESTRIAN,
-    TRAVEL_MODE_PUBLIC,
-    TRAVEL_MODE_PUBLIC_TIME_TABLE,
-    TRAVEL_MODE_TRUCK,
-    TRAVEL_MODES,
-    UNITS,
+    IMPERIAL_UNITS,
 )
 
-_LOGGER = logging.getLogger(__name__)
-
-
 SCAN_INTERVAL = timedelta(minutes=5)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
-    {
-        vol.Required(CONF_API_KEY): cv.string,
-        vol.Inclusive(
-            CONF_DESTINATION_LATITUDE, "destination_coordinates"
-        ): cv.latitude,
-        vol.Inclusive(
-            CONF_DESTINATION_LONGITUDE, "destination_coordinates"
-        ): cv.longitude,
-        vol.Exclusive(CONF_DESTINATION_LATITUDE, "destination"): cv.latitude,
-        vol.Exclusive(CONF_DESTINATION_ENTITY_ID, "destination"): cv.entity_id,
-        vol.Inclusive(CONF_ORIGIN_LATITUDE, "origin_coordinates"): cv.latitude,
-        vol.Inclusive(CONF_ORIGIN_LONGITUDE, "origin_coordinates"): cv.longitude,
-        vol.Exclusive(CONF_ORIGIN_LATITUDE, "origin"): cv.latitude,
-        vol.Exclusive(CONF_ORIGIN_ENTITY_ID, "origin"): cv.entity_id,
-        vol.Optional(CONF_DEPARTURE): cv.time,
-        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-        vol.Optional(CONF_MODE, default=TRAVEL_MODE_CAR): vol.In(TRAVEL_MODES),
-        vol.Optional(CONF_ROUTE_MODE, default=ROUTE_MODE_FASTEST): vol.In(ROUTE_MODES),
-        vol.Optional(CONF_TRAFFIC_MODE, default=False): cv.boolean,
-        vol.Optional(CONF_UNIT_SYSTEM): vol.In(UNITS),
-    }
-)
-
-PLATFORM_SCHEMA = vol.All(
-    cv.has_at_least_one_key(CONF_DESTINATION_LATITUDE, CONF_DESTINATION_ENTITY_ID),
-    cv.has_at_least_one_key(CONF_ORIGIN_LATITUDE, CONF_ORIGIN_ENTITY_ID),
-    cv.key_value_schemas(
-        CONF_MODE,
-        {
-            None: PLATFORM_SCHEMA,
-            TRAVEL_MODE_BICYCLE: PLATFORM_SCHEMA,
-            TRAVEL_MODE_CAR: PLATFORM_SCHEMA,
-            TRAVEL_MODE_PEDESTRIAN: PLATFORM_SCHEMA,
-            TRAVEL_MODE_PUBLIC: PLATFORM_SCHEMA,
-            TRAVEL_MODE_TRUCK: PLATFORM_SCHEMA,
-            TRAVEL_MODE_PUBLIC_TIME_TABLE: PLATFORM_SCHEMA.extend(
-                {
-                    vol.Exclusive(CONF_ARRIVAL, "arrival_departure"): cv.time,
-                    vol.Exclusive(CONF_DEPARTURE, "arrival_departure"): cv.time,
-                }
-            ),
-        },
-    ),
-)
-
 
 def sensor_descriptions(travel_mode: str) -> tuple[SensorEntityDescription, ...]:
     """Construct SensorEntityDescriptions."""
@@ -133,45 +57,12 @@ def sensor_descriptions(travel_mode: str) -> tuple[SensorEntityDescription, ...]
             native_unit_of_measurement=TIME_MINUTES,
         ),
         SensorEntityDescription(
-            name="Duration in Traffic",
+            name="Duration in traffic",
             icon=ICONS.get(travel_mode, ICON_CAR),
             key=ATTR_DURATION_IN_TRAFFIC,
             state_class=SensorStateClass.MEASUREMENT,
             native_unit_of_measurement=TIME_MINUTES,
         ),
-        SensorEntityDescription(
-            name="Distance",
-            icon=ICONS.get(travel_mode, ICON_CAR),
-            key=ATTR_DISTANCE,
-            state_class=SensorStateClass.MEASUREMENT,
-        ),
-        SensorEntityDescription(
-            name="Route",
-            icon="mdi:directions",
-            key=ATTR_ROUTE,
-        ),
-    )
-
-
-async def async_setup_platform(
-    hass: HomeAssistant,
-    config: ConfigType,
-    async_add_entities: AddEntitiesCallback,
-    discovery_info: DiscoveryInfoType | None = None,
-) -> None:
-    """Set up the HERE travel time platform."""
-    hass.async_create_task(
-        hass.config_entries.flow.async_init(
-            DOMAIN,
-            context={"source": SOURCE_IMPORT},
-            data=config,
-        )
-    )
-
-    _LOGGER.warning(
-        "Your HERE travel time configuration has been imported into the UI; "
-        "please remove it from configuration.yaml as support for it will be "
-        "removed in a future release"
     )
 
 
@@ -198,6 +89,7 @@ async def async_setup_entry(
         )
     sensors.append(OriginSensor(entry_id, name, coordinator))
     sensors.append(DestinationSensor(entry_id, name, coordinator))
+    sensors.append(DistanceSensor(entry_id, name, coordinator))
     async_add_entities(sensors)
 
 
@@ -214,7 +106,6 @@ class HERETravelTimeSensor(SensorEntity, CoordinatorEntity):
         """Initialize the sensor."""
         super().__init__(coordinator)
         self.entity_description = sensor_description
-        self._attr_name = f"{name} {sensor_description.name}"
         self._attr_unique_id = f"{unique_id_prefix}_{sensor_description.key}"
         self._attr_device_info = DeviceInfo(
             identifiers={(DOMAIN, unique_id_prefix)},
@@ -222,6 +113,7 @@ class HERETravelTimeSensor(SensorEntity, CoordinatorEntity):
             name=name,
             manufacturer="HERE Technologies",
         )
+        self._attr_has_entity_name = True
 
     async def async_added_to_hass(self) -> None:
         """Wait for start so origin and destination entities can be resolved."""
@@ -301,3 +193,29 @@ class DestinationSensor(HERETravelTimeSensor):
                 ATTR_LONGITUDE: self.coordinator.data[ATTR_DESTINATION].split(",")[1],
             }
         return None
+
+
+class DistanceSensor(HERETravelTimeSensor):
+    """Sensor holding information about the distance."""
+
+    def __init__(
+        self,
+        unique_id_prefix: str,
+        name: str,
+        coordinator: HereTravelTimeDataUpdateCoordinator,
+    ) -> None:
+        """Initialize the sensor."""
+        sensor_description = SensorEntityDescription(
+            name="Distance",
+            icon=ICONS.get(coordinator.config.travel_mode, ICON_CAR),
+            key=ATTR_DISTANCE,
+            state_class=SensorStateClass.MEASUREMENT,
+        )
+        super().__init__(unique_id_prefix, name, sensor_description, coordinator)
+
+    @property
+    def native_unit_of_measurement(self) -> str | None:
+        """Return the unit of measurement of the sensor."""
+        if self.coordinator.config.units == IMPERIAL_UNITS:
+            return LENGTH_MILES
+        return LENGTH_KILOMETERS
