@@ -354,7 +354,25 @@ class IBeaconCoordinator:
             for group_id in self._group_ids_random_macs
             if group_id not in self._unavailable_group_ids
             and (service_info := self._last_seen_by_group_id.get(group_id))
-            and now - service_info.time > UNAVAILABLE_TIMEOUT
+            and (
+                # We will not be callbacks for iBeacons with random macs
+                # that rotate infrequently since their advertisement data is
+                # does not change as the bluetooth.async_register_callback API
+                # suppresses callbacks for duplicate advertisements to avoid
+                # exposing integrations to the firehose of bluetooth advertisements.
+                #
+                # To solve this we need to ask for the latest service info for
+                # the address we last saw to get the latest timestamp.
+                #
+                # If there is no last service info for the address we know that
+                # the device is no longer advertising.
+                not (
+                    latest_service_info := bluetooth.async_last_service_info(
+                        self.hass, service_info.address, connectable=False
+                    )
+                )
+                or now - latest_service_info.time > UNAVAILABLE_TIMEOUT
+            )
         ]
         for group_id in gone_unavailable:
             self._unavailable_group_ids.add(group_id)
