@@ -3,6 +3,7 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import Callable
+from datetime import datetime
 import logging
 from typing import Any, cast
 
@@ -13,10 +14,12 @@ from homeassistant import config as conf_util, config_entries
 from homeassistant.components import websocket_api
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
+    CONF_CLIENT_ID,
     CONF_DISCOVERY,
     CONF_PASSWORD,
     CONF_PAYLOAD,
     CONF_PORT,
+    CONF_PROTOCOL,
     CONF_USERNAME,
     SERVICE_RELOAD,
 )
@@ -31,6 +34,7 @@ from homeassistant.helpers import (
 from homeassistant.helpers.device_registry import DeviceEntry
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity_platform import async_get_platforms
+from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.reload import (
     async_integration_yaml_config,
     async_reload_integration_platforms,
@@ -49,7 +53,9 @@ from .client import (  # noqa: F401
 )
 from .config_integration import (
     CONFIG_SCHEMA_BASE,
+    CONFIG_SCHEMA_ENTRY,
     DEFAULT_VALUES,
+    DEPRECATED_CERTIFICATE_CONFIG_KEYS,
     DEPRECATED_CONFIG_KEYS,
 )
 from .const import (  # noqa: F401
@@ -59,10 +65,15 @@ from .const import (  # noqa: F401
     ATTR_TOPIC,
     CONF_BIRTH_MESSAGE,
     CONF_BROKER,
+    CONF_CERTIFICATE,
+    CONF_CLIENT_CERT,
+    CONF_CLIENT_KEY,
     CONF_COMMAND_TOPIC,
     CONF_DISCOVERY_PREFIX,
+    CONF_KEEPALIVE,
     CONF_QOS,
     CONF_STATE_TOPIC,
+    CONF_TLS_INSECURE,
     CONF_TLS_VERSION,
     CONF_TOPIC,
     CONF_WILL_MESSAGE,
@@ -76,7 +87,6 @@ from .const import (  # noqa: F401
     PLATFORMS,
     RELOADABLE_PLATFORMS,
 )
-from .mixins import MqttData
 from .models import (  # noqa: F401
     MqttCommandTemplate,
     MqttValueTemplate,
@@ -86,6 +96,9 @@ from .models import (  # noqa: F401
 )
 from .util import (
     _VALID_QOS_SCHEMA,
+    async_create_certificate_temp_files,
+    get_mqtt_data,
+    migrate_certificate_file_to_content,
     mqtt_config_entry_enabled,
     valid_publish_topic,
     valid_subscribe_topic,
@@ -96,7 +109,7 @@ _LOGGER = logging.getLogger(__name__)
 SERVICE_PUBLISH = "publish"
 SERVICE_DUMP = "dump"
 
-MANDATORY_DEFAULT_VALUES = (CONF_PORT,)
+MANDATORY_DEFAULT_VALUES = (CONF_PORT, CONF_DISCOVERY_PREFIX)
 
 ATTR_TOPIC_TEMPLATE = "topic_template"
 ATTR_PAYLOAD_TEMPLATE = "payload_template"
@@ -110,9 +123,17 @@ CONNECTION_FAILED_RECOVERABLE = "connection_failed_recoverable"
 CONFIG_ENTRY_CONFIG_KEYS = [
     CONF_BIRTH_MESSAGE,
     CONF_BROKER,
+    CONF_CERTIFICATE,
+    CONF_CLIENT_ID,
+    CONF_CLIENT_CERT,
+    CONF_CLIENT_KEY,
     CONF_DISCOVERY,
+    CONF_DISCOVERY_PREFIX,
+    CONF_KEEPALIVE,
     CONF_PASSWORD,
     CONF_PORT,
+    CONF_PROTOCOL,
+    CONF_TLS_INSECURE,
     CONF_USERNAME,
     CONF_WILL_MESSAGE,
 ]
@@ -122,9 +143,17 @@ CONFIG_SCHEMA = vol.Schema(
         DOMAIN: vol.All(
             cv.deprecated(CONF_BIRTH_MESSAGE),  # Deprecated in HA Core 2022.3
             cv.deprecated(CONF_BROKER),  # Deprecated in HA Core 2022.3
+            cv.deprecated(CONF_CERTIFICATE),  # Deprecated in HA Core 2022.11
+            cv.deprecated(CONF_CLIENT_ID),  # Deprecated in HA Core 2022.11
+            cv.deprecated(CONF_CLIENT_CERT),  # Deprecated in HA Core 2022.11
+            cv.deprecated(CONF_CLIENT_KEY),  # Deprecated in HA Core 2022.11
             cv.deprecated(CONF_DISCOVERY),  # Deprecated in HA Core 2022.3
+            cv.deprecated(CONF_DISCOVERY_PREFIX),  # Deprecated in HA Core 2022.11
+            cv.deprecated(CONF_KEEPALIVE),  # Deprecated in HA Core 2022.11
             cv.deprecated(CONF_PASSWORD),  # Deprecated in HA Core 2022.3
             cv.deprecated(CONF_PORT),  # Deprecated in HA Core 2022.3
+            cv.deprecated(CONF_PROTOCOL),  # Deprecated in HA Core 2022.11
+            cv.deprecated(CONF_TLS_INSECURE),  # Deprecated in HA Core 2022.11
             cv.deprecated(CONF_TLS_VERSION),  # Deprecated June 2020
             cv.deprecated(CONF_USERNAME),  # Deprecated in HA Core 2022.3
             cv.deprecated(CONF_WILL_MESSAGE),  # Deprecated in HA Core 2022.3
@@ -153,7 +182,7 @@ MQTT_PUBLISH_SCHEMA = vol.All(
 
 
 async def _async_setup_discovery(
-    hass: HomeAssistant, conf: ConfigType, config_entry
+    hass: HomeAssistant, conf: ConfigType, config_entry: ConfigEntry
 ) -> None:
     """Try to start the discovery of MQTT devices.
 
@@ -164,13 +193,12 @@ async def _async_setup_discovery(
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Start the MQTT protocol service."""
-    mqtt_data: MqttData = hass.data.setdefault(DATA_MQTT, MqttData())
+    mqtt_data = get_mqtt_data(hass, True)
 
     conf: ConfigType | None = config.get(DOMAIN)
 
     websocket_api.async_register_command(hass, websocket_subscribe)
     websocket_api.async_register_command(hass, websocket_mqtt_info)
-    debug_info.initialize(hass)
 
     if conf:
         conf = dict(conf)
@@ -207,22 +235,31 @@ def _filter_entry_config(hass: HomeAssistant, entry: ConfigEntry) -> None:
     if entry.data.keys() != filtered_data.keys():
         _LOGGER.warning(
             "The following unsupported configuration options were removed from the "
-            "MQTT config entry: %s. Add them to configuration.yaml if they are needed",
+            "MQTT config entry: %s",
             entry.data.keys() - filtered_data.keys(),
         )
         hass.config_entries.async_update_entry(entry, data=filtered_data)
 
 
-def _merge_basic_config(
+async def _async_merge_basic_config(
     hass: HomeAssistant, entry: ConfigEntry, yaml_config: dict[str, Any]
 ) -> None:
     """Merge basic options in configuration.yaml config with config entry.
 
     This mends incomplete migration from old version of HA Core.
     """
-
     entry_updated = False
     entry_config = {**entry.data}
+    for key in DEPRECATED_CERTIFICATE_CONFIG_KEYS:
+        if key in yaml_config and key not in entry_config:
+            if (
+                content := await hass.async_add_executor_job(
+                    migrate_certificate_file_to_content, yaml_config[key]
+                )
+            ) is not None:
+                entry_config[key] = content
+                entry_updated = True
+
     for key in DEPRECATED_CONFIG_KEYS:
         if key in yaml_config and key not in entry_config:
             entry_config[key] = yaml_config[key]
@@ -237,7 +274,7 @@ def _merge_basic_config(
         hass.config_entries.async_update_entry(entry, data=entry_config)
 
 
-def _merge_extended_config(entry, conf):
+def _merge_extended_config(entry: ConfigEntry, conf: ConfigType) -> dict[str, Any]:
     """Merge advanced options in configuration.yaml config with config entry."""
     # Add default values
     conf = {**DEFAULT_VALUES, **conf}
@@ -249,25 +286,14 @@ async def _async_config_entry_updated(hass: HomeAssistant, entry: ConfigEntry) -
 
     Causes for this is config entry options changing.
     """
-    mqtt_data: MqttData = hass.data[DATA_MQTT]
-    assert (client := mqtt_data.client) is not None
-
-    if (conf := mqtt_data.config) is None:
-        conf = CONFIG_SCHEMA_BASE(dict(entry.data))
-
-    mqtt_data.config = _merge_extended_config(entry, conf)
-    await client.async_disconnect()
-    client.init_client()
-    await client.async_connect()
-
-    await discovery.async_stop(hass)
-    if client.conf.get(CONF_DISCOVERY):
-        await _async_setup_discovery(hass, cast(ConfigType, mqtt_data.config), entry)
+    await hass.config_entries.async_reload(entry.entry_id)
 
 
-async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict | None:
+async def async_fetch_config(
+    hass: HomeAssistant, entry: ConfigEntry
+) -> dict[str, Any] | None:
     """Fetch fresh MQTT yaml config from the hass config when (re)loading the entry."""
-    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    mqtt_data = get_mqtt_data(hass)
     if mqtt_data.reload_entry:
         hass_config = await conf_util.async_hass_config_yaml(hass)
         mqtt_data.config = CONFIG_SCHEMA_BASE(hass_config.get(DOMAIN, {}))
@@ -276,7 +302,7 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
     _filter_entry_config(hass, entry)
 
     # Merge basic configuration, and add missing defaults for basic options
-    _merge_basic_config(hass, entry, mqtt_data.config or {})
+    await _async_merge_basic_config(hass, entry, mqtt_data.config or {})
     # Bail out if broker setting is missing
     if CONF_BROKER not in entry.data:
         _LOGGER.error("MQTT broker is not configured, please configure it")
@@ -285,7 +311,7 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
     # If user doesn't have configuration.yaml config, generate default values
     # for options not in config entry data
     if (conf := mqtt_data.config) is None:
-        conf = CONFIG_SCHEMA_BASE(dict(entry.data))
+        conf = CONFIG_SCHEMA_ENTRY(dict(entry.data))
 
     # User has configuration.yaml config, warn about config entry overrides
     elif any(key in conf for key in entry.data):
@@ -293,12 +319,28 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
         override = {k: entry.data[k] for k in shared_keys if conf[k] != entry.data[k]}
         if CONF_PASSWORD in override:
             override[CONF_PASSWORD] = "********"
+        if CONF_CLIENT_KEY in override:
+            override[CONF_CLIENT_KEY] = "-----PRIVATE KEY-----"
         if override:
             _LOGGER.warning(
                 "Deprecated configuration settings found in configuration.yaml. "
                 "These settings from your configuration entry will override: %s",
                 override,
             )
+        # Register a repair issue
+        async_create_issue(
+            hass,
+            DOMAIN,
+            "deprecated_yaml_broker_settings",
+            breaks_in_ha_version="2023.4.0",  # Warning first added in 2022.11.0
+            is_fixable=False,
+            severity=IssueSeverity.WARNING,
+            translation_key="deprecated_yaml_broker_settings",
+            translation_placeholders={
+                "more_info_url": "https://www.home-assistant.io/integrations/mqtt/",
+                "deprecated_settings": str(shared_keys)[1:-1],
+            },
+        )
 
     # Merge advanced configuration values from configuration.yaml
     conf = _merge_extended_config(entry, conf)
@@ -307,18 +349,21 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Load a config entry."""
-    mqtt_data: MqttData = hass.data.setdefault(DATA_MQTT, MqttData())
+    mqtt_data = get_mqtt_data(hass, True)
 
     # Merge basic configuration, and add missing defaults for basic options
     if (conf := await async_fetch_config(hass, entry)) is None:
         # Bail out
         return False
+    await async_create_certificate_temp_files(hass, dict(entry.data))
     mqtt_data.client = MQTT(hass, entry, conf)
     # Restore saved subscriptions
     if mqtt_data.subscriptions_to_restore:
         mqtt_data.client.subscriptions = mqtt_data.subscriptions_to_restore
         mqtt_data.subscriptions_to_restore = []
-    entry.add_update_listener(_async_config_entry_updated)
+    mqtt_data.reload_dispatchers.append(
+        entry.add_update_listener(_async_config_entry_updated)
+    )
 
     await mqtt_data.client.async_connect()
 
@@ -332,7 +377,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         retain: bool = call.data[ATTR_RETAIN]
         if msg_topic_template is not None:
             try:
-                rendered_topic = template.Template(
+                rendered_topic: Any = template.Template(
                     msg_topic_template, hass
                 ).async_render(parse_result=False)
                 msg_topic = valid_publish_topic(rendered_topic)
@@ -378,20 +423,20 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     async def async_dump_service(call: ServiceCall) -> None:
         """Handle MQTT dump service calls."""
-        messages = []
+        messages: list[tuple[str, str]] = []
 
         @callback
-        def collect_msg(msg):
-            messages.append((msg.topic, msg.payload.replace("\n", "")))
+        def collect_msg(msg: ReceiveMessage) -> None:
+            messages.append((msg.topic, str(msg.payload).replace("\n", "")))
 
         unsub = await async_subscribe(hass, call.data["topic"], collect_msg)
 
-        def write_dump():
-            with open(hass.config.path("mqtt_dump.txt"), "wt", encoding="utf8") as fp:
+        def write_dump() -> None:
+            with open(hass.config.path("mqtt_dump.txt"), "w", encoding="utf8") as fp:
                 for msg in messages:
                     fp.write(",".join(msg) + "\n")
 
-        async def finish_dump(_):
+        async def finish_dump(_: datetime) -> None:
             """Write dump to file."""
             unsub()
             await hass.async_add_executor_job(write_dump)
@@ -451,7 +496,10 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
         async_register_admin_service(hass, DOMAIN, SERVICE_RELOAD, _reload_config)
 
-    async def async_forward_entry_setup_and_setup_discovery(config_entry):
+    async def async_forward_entry_setup_and_setup_discovery(
+        config_entry: ConfigEntry,
+        conf: ConfigType,
+    ) -> None:
         """Forward the config entry setup to the platforms and set up discovery."""
         reload_manual_setup: bool = False
         # Local import to avoid circular dependencies
@@ -489,7 +537,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         if reload_manual_setup:
             await async_reload_manual_mqtt_items(hass)
 
-    await async_forward_entry_setup_and_setup_discovery(entry)
+    await async_forward_entry_setup_and_setup_discovery(entry, conf)
 
     return True
 
@@ -508,7 +556,9 @@ async def async_reload_manual_mqtt_items(hass: HomeAssistant) -> None:
     {vol.Required("type"): "mqtt/device/debug_info", vol.Required("device_id"): str}
 )
 @callback
-def websocket_mqtt_info(hass, connection, msg):
+def websocket_mqtt_info(
+    hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict[str, Any]
+) -> None:
     """Get MQTT debug info for device."""
     device_id = msg["device_id"]
     mqtt_info = debug_info.info_for_device(hass, device_id)
@@ -523,12 +573,14 @@ def websocket_mqtt_info(hass, connection, msg):
     }
 )
 @websocket_api.async_response
-async def websocket_subscribe(hass, connection, msg):
+async def websocket_subscribe(
+    hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict[str, Any]
+) -> None:
     """Subscribe to a MQTT topic."""
     if not connection.user.is_admin:
         raise Unauthorized
 
-    async def forward_messages(mqttmsg: ReceiveMessage):
+    async def forward_messages(mqttmsg: ReceiveMessage) -> None:
         """Forward events to websocket."""
         try:
             payload = cast(bytes, mqttmsg.payload).decode(
@@ -568,12 +620,12 @@ def async_subscribe_connection_status(
     """Subscribe to MQTT connection changes."""
     connection_status_callback_job = HassJob(connection_status_callback)
 
-    async def connected():
+    async def connected() -> None:
         task = hass.async_run_hass_job(connection_status_callback_job, True)
         if task:
             await task
 
-    async def disconnected():
+    async def disconnected() -> None:
         task = hass.async_run_hass_job(connection_status_callback_job, False)
         if task:
             await task
@@ -584,7 +636,7 @@ def async_subscribe_connection_status(
     }
 
     @callback
-    def unsubscribe():
+    def unsubscribe() -> None:
         subscriptions["connect"]()
         subscriptions["disconnect"]()
 
@@ -593,7 +645,7 @@ def async_subscribe_connection_status(
 
 def is_connected(hass: HomeAssistant) -> bool:
     """Return if MQTT client is connected."""
-    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    mqtt_data = get_mqtt_data(hass)
     assert mqtt_data.client is not None
     return mqtt_data.client.connected
 
@@ -611,7 +663,7 @@ async def async_remove_config_entry_device(
 
 async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload MQTT dump and publish service when the config entry is unloaded."""
-    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    mqtt_data = get_mqtt_data(hass)
     assert mqtt_data.client is not None
     mqtt_client = mqtt_data.client
 
