@@ -1,26 +1,21 @@
 """Media Player component to integrate TVs exposing the Joint Space API."""
 from __future__ import annotations
 
+from typing import Any
+
 from haphilipsjs import ConnectionFailure
 
 from homeassistant.components.media_player import (
+    BrowseError,
     BrowseMedia,
+    MediaClass,
     MediaPlayerDeviceClass,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
+    MediaType,
 )
-from homeassistant.components.media_player.const import (
-    MEDIA_CLASS_APP,
-    MEDIA_CLASS_CHANNEL,
-    MEDIA_CLASS_DIRECTORY,
-    MEDIA_TYPE_APP,
-    MEDIA_TYPE_APPS,
-    MEDIA_TYPE_CHANNEL,
-    MEDIA_TYPE_CHANNELS,
-)
-from homeassistant.components.media_player.errors import BrowseError
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import STATE_OFF, STATE_ON
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -94,7 +89,7 @@ class PhilipsTVMediaPlayer(
             sw_version=coordinator.system.get("softwareversion"),
             name=coordinator.system["name"],
         )
-        self._state = STATE_OFF
+        self._state = MediaPlayerState.OFF
         self._media_content_type: str | None = None
         self._media_content_id: str | None = None
         self._media_title: str | None = None
@@ -119,11 +114,11 @@ class PhilipsTVMediaPlayer(
         return supports
 
     @property
-    def state(self):
+    def state(self) -> MediaPlayerState:
         """Get the device state. An exception means OFF state."""
         if self._tv.on and (self._tv.powerstate == "On" or self._tv.powerstate is None):
-            return STATE_ON
-        return STATE_OFF
+            return MediaPlayerState.ON
+        return MediaPlayerState.OFF
 
     @property
     def source(self):
@@ -135,7 +130,7 @@ class PhilipsTVMediaPlayer(
         """List of available input sources."""
         return list(self._sources.values())
 
-    async def async_select_source(self, source):
+    async def async_select_source(self, source: str) -> None:
         """Set the input source."""
         if source_id := _inverted(self._sources).get(source):
             await self._tv.setSource(source_id)
@@ -151,35 +146,35 @@ class PhilipsTVMediaPlayer(
         """Boolean if volume is currently muted."""
         return self._tv.muted
 
-    async def async_turn_on(self):
+    async def async_turn_on(self) -> None:
         """Turn on the device."""
         if self._tv.on and self._tv.powerstate:
             await self._tv.setPowerState("On")
-            self._state = STATE_ON
+            self._state = MediaPlayerState.ON
         else:
             await self.coordinator.turn_on.async_run(self.hass, self._context)
         await self._async_update_soon()
 
-    async def async_turn_off(self):
+    async def async_turn_off(self) -> None:
         """Turn off the device."""
-        if self._state == STATE_ON:
+        if self._state == MediaPlayerState.ON:
             await self._tv.sendKey("Standby")
-            self._state = STATE_OFF
+            self._state = MediaPlayerState.OFF
             await self._async_update_soon()
         else:
             _LOGGER.debug("Ignoring turn off when already in expected state")
 
-    async def async_volume_up(self):
+    async def async_volume_up(self) -> None:
         """Send volume up command."""
         await self._tv.sendKey("VolumeUp")
         await self._async_update_soon()
 
-    async def async_volume_down(self):
+    async def async_volume_down(self) -> None:
         """Send volume down command."""
         await self._tv.sendKey("VolumeDown")
         await self._async_update_soon()
 
-    async def async_mute_volume(self, mute):
+    async def async_mute_volume(self, mute: bool) -> None:
         """Send mute command."""
         if self._tv.muted != mute:
             await self._tv.sendKey("Mute")
@@ -187,22 +182,22 @@ class PhilipsTVMediaPlayer(
         else:
             _LOGGER.debug("Ignoring request when already in expected state")
 
-    async def async_set_volume_level(self, volume):
+    async def async_set_volume_level(self, volume: float) -> None:
         """Set volume level, range 0..1."""
         await self._tv.setVolume(volume, self._tv.muted)
         await self._async_update_soon()
 
-    async def async_media_previous_track(self):
+    async def async_media_previous_track(self) -> None:
         """Send rewind command."""
         await self._tv.sendKey("Previous")
         await self._async_update_soon()
 
-    async def async_media_next_track(self):
+    async def async_media_next_track(self) -> None:
         """Send fast forward command."""
         await self._tv.sendKey("Next")
         await self._async_update_soon()
 
-    async def async_media_play_pause(self):
+    async def async_media_play_pause(self) -> None:
         """Send pause command to media player."""
         if self._tv.quirk_playpause_spacebar:
             await self._tv.sendUnicode(" ")
@@ -210,17 +205,17 @@ class PhilipsTVMediaPlayer(
             await self._tv.sendKey("PlayPause")
         await self._async_update_soon()
 
-    async def async_media_play(self):
+    async def async_media_play(self) -> None:
         """Send pause command to media player."""
         await self._tv.sendKey("Play")
         await self._async_update_soon()
 
-    async def async_media_pause(self):
+    async def async_media_pause(self) -> None:
         """Send play command to media player."""
         await self._tv.sendKey("Pause")
         await self._async_update_soon()
 
-    async def async_media_stop(self):
+    async def async_media_stop(self) -> None:
         """Send play command to media player."""
         await self._tv.sendKey("Stop")
         await self._async_update_soon()
@@ -249,8 +244,8 @@ class PhilipsTVMediaPlayer(
     def media_image_url(self):
         """Image url of current playing media."""
         if self._media_content_id and self._media_content_type in (
-            MEDIA_TYPE_APP,
-            MEDIA_TYPE_CHANNEL,
+            MediaType.APP,
+            MediaType.CHANNEL,
         ):
             return self.get_browse_image_url(
                 self._media_content_type, self._media_content_id, media_image_id=None
@@ -268,18 +263,20 @@ class PhilipsTVMediaPlayer(
         if app := self._tv.applications.get(self._tv.application_id):
             return app.get("label")
 
-    async def async_play_media(self, media_type, media_id, **kwargs):
+    async def async_play_media(
+        self, media_type: str, media_id: str, **kwargs: Any
+    ) -> None:
         """Play a piece of media."""
         _LOGGER.debug("Call play media type <%s>, Id <%s>", media_type, media_id)
 
-        if media_type == MEDIA_TYPE_CHANNEL:
+        if media_type == MediaType.CHANNEL:
             list_id, _, channel_id = media_id.partition("/")
             if channel_id:
                 await self._tv.setChannel(channel_id, list_id)
                 await self._async_update_soon()
             else:
                 _LOGGER.error("Unable to find channel <%s>", media_id)
-        elif media_type == MEDIA_TYPE_APP:
+        elif media_type == MediaType.APP:
             if app := self._tv.applications.get(media_id):
                 await self._tv.setApplication(app["intent"])
                 await self._async_update_soon()
@@ -294,9 +291,9 @@ class PhilipsTVMediaPlayer(
             children = [
                 BrowseMedia(
                     title=channel.get("name", f"Channel: {channel_id}"),
-                    media_class=MEDIA_CLASS_CHANNEL,
+                    media_class=MediaClass.CHANNEL,
                     media_content_id=f"alltv/{channel_id}",
-                    media_content_type=MEDIA_TYPE_CHANNEL,
+                    media_content_type=MediaType.CHANNEL,
                     can_play=True,
                     can_expand=False,
                 )
@@ -307,10 +304,10 @@ class PhilipsTVMediaPlayer(
 
         return BrowseMedia(
             title="Channels",
-            media_class=MEDIA_CLASS_DIRECTORY,
+            media_class=MediaClass.DIRECTORY,
             media_content_id="channels",
-            media_content_type=MEDIA_TYPE_CHANNELS,
-            children_media_class=MEDIA_CLASS_CHANNEL,
+            media_content_type=MediaType.CHANNELS,
+            children_media_class=MediaClass.CHANNEL,
             can_play=False,
             can_expand=True,
             children=children,
@@ -331,9 +328,9 @@ class PhilipsTVMediaPlayer(
                 children = [
                     BrowseMedia(
                         title=get_name(channel),
-                        media_class=MEDIA_CLASS_CHANNEL,
+                        media_class=MediaClass.CHANNEL,
                         media_content_id=f"{list_id}/{channel['ccid']}",
-                        media_content_type=MEDIA_TYPE_CHANNEL,
+                        media_content_type=MediaType.CHANNEL,
                         can_play=True,
                         can_expand=False,
                     )
@@ -347,10 +344,10 @@ class PhilipsTVMediaPlayer(
         favorite = self._tv.favorite_lists[list_id]
         return BrowseMedia(
             title=favorite.get("name", f"Favorites {list_id}"),
-            media_class=MEDIA_CLASS_DIRECTORY,
+            media_class=MediaClass.DIRECTORY,
             media_content_id=f"favorites/{list_id}",
-            media_content_type=MEDIA_TYPE_CHANNELS,
-            children_media_class=MEDIA_CLASS_CHANNEL,
+            media_content_type=MediaType.CHANNELS,
+            children_media_class=MediaClass.CHANNEL,
             can_play=False,
             can_expand=True,
             children=children,
@@ -362,13 +359,13 @@ class PhilipsTVMediaPlayer(
             children = [
                 BrowseMedia(
                     title=application["label"],
-                    media_class=MEDIA_CLASS_APP,
+                    media_class=MediaClass.APP,
                     media_content_id=application_id,
-                    media_content_type=MEDIA_TYPE_APP,
+                    media_content_type=MediaType.APP,
                     can_play=True,
                     can_expand=False,
                     thumbnail=self.get_browse_image_url(
-                        MEDIA_TYPE_APP, application_id, media_image_id=None
+                        MediaType.APP, application_id, media_image_id=None
                     ),
                 )
                 for application_id, application in self._tv.applications.items()
@@ -378,10 +375,10 @@ class PhilipsTVMediaPlayer(
 
         return BrowseMedia(
             title="Applications",
-            media_class=MEDIA_CLASS_DIRECTORY,
+            media_class=MediaClass.DIRECTORY,
             media_content_id="applications",
-            media_content_type=MEDIA_TYPE_APPS,
-            children_media_class=MEDIA_CLASS_APP,
+            media_content_type=MediaType.APPS,
+            children_media_class=MediaClass.APP,
             can_play=False,
             can_expand=True,
             children=children,
@@ -399,10 +396,10 @@ class PhilipsTVMediaPlayer(
 
         return BrowseMedia(
             title="Favorites",
-            media_class=MEDIA_CLASS_DIRECTORY,
+            media_class=MediaClass.DIRECTORY,
             media_content_id="favorite_lists",
-            media_content_type=MEDIA_TYPE_CHANNELS,
-            children_media_class=MEDIA_CLASS_CHANNEL,
+            media_content_type=MediaType.CHANNELS,
+            children_media_class=MediaClass.CHANNEL,
             can_play=False,
             can_expand=True,
             children=children,
@@ -413,7 +410,7 @@ class PhilipsTVMediaPlayer(
 
         return BrowseMedia(
             title="Philips TV",
-            media_class=MEDIA_CLASS_DIRECTORY,
+            media_class=MediaClass.DIRECTORY,
             media_content_id="",
             media_content_type="",
             can_play=False,
@@ -452,15 +449,15 @@ class PhilipsTVMediaPlayer(
     ) -> tuple[bytes | None, str | None]:
         """Serve album art. Returns (content, content_type)."""
         try:
-            if media_content_type == MEDIA_TYPE_APP and media_content_id:
+            if media_content_type == MediaType.APP and media_content_id:
                 return await self._tv.getApplicationIcon(media_content_id)
-            if media_content_type == MEDIA_TYPE_CHANNEL and media_content_id:
+            if media_content_type == MediaType.CHANNEL and media_content_id:
                 return await self._tv.getChannelLogo(media_content_id)
         except ConnectionFailure:
             _LOGGER.warning("Failed to fetch image")
         return None, None
 
-    async def async_get_media_image(self):
+    async def async_get_media_image(self) -> tuple[bytes | None, str | None]:
         """Serve album art. Returns (content, content_type)."""
         return await self.async_get_browse_image(
             self.media_content_type, self.media_content_id, None
@@ -471,11 +468,11 @@ class PhilipsTVMediaPlayer(
 
         if self._tv.on:
             if self._tv.powerstate in ("Standby", "StandbyKeep"):
-                self._state = STATE_OFF
+                self._state = MediaPlayerState.OFF
             else:
-                self._state = STATE_ON
+                self._state = MediaPlayerState.ON
         else:
-            self._state = STATE_OFF
+            self._state = MediaPlayerState.OFF
 
         self._sources = {
             srcid: source.get("name") or f"Source {srcid}"
@@ -483,14 +480,14 @@ class PhilipsTVMediaPlayer(
         }
 
         if self._tv.channel_active:
-            self._media_content_type = MEDIA_TYPE_CHANNEL
+            self._media_content_type = MediaType.CHANNEL
             self._media_content_id = f"all/{self._tv.channel_id}"
             self._media_title = self._tv.channels.get(self._tv.channel_id, {}).get(
                 "name"
             )
             self._media_channel = self._media_title
         elif self._tv.application_id:
-            self._media_content_type = MEDIA_TYPE_APP
+            self._media_content_type = MediaType.APP
             self._media_content_id = self._tv.application_id
             self._media_title = self._tv.applications.get(
                 self._tv.application_id, {}
