@@ -44,12 +44,10 @@ from homeassistant.core import CALLBACK_TYPE, HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers import config_entry_oauth2_flow, entity_registry as er
 from homeassistant.helpers.config_entry_oauth2_flow import (
-    AUTH_CALLBACK_PATH,
     AbstractOAuth2Implementation,
     OAuth2Session,
 )
 from homeassistant.helpers.entity import Entity
-from homeassistant.helpers.network import get_url
 from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 from homeassistant.util import dt
 
@@ -503,6 +501,7 @@ class ConfigEntryWithingsApi(AbstractWithingsApi):
             f"{self.URL}/{path}",
             params=params,
             headers={"Authorization": f"Bearer {access_token}"},
+            timeout=10,
         )
         return response.json()
 
@@ -911,6 +910,8 @@ async def async_get_entity_id(
 class BaseWithingsSensor(Entity):
     """Base class for withings sensors."""
 
+    _attr_should_poll = False
+
     def __init__(self, data_manager: DataManager, attribute: WithingsAttribute) -> None:
         """Initialize the Withings sensor."""
         self._data_manager = data_manager
@@ -921,11 +922,6 @@ class BaseWithingsSensor(Entity):
         self._unique_id = get_attribute_unique_id(self._attribute, self._user_id)
         self._state_data: Any | None = None
 
-    @property
-    def should_poll(self) -> bool:
-        """Return False to indicate HA should not poll for changes."""
-        return False
-
     @property
     def name(self) -> str:
         """Return the name of the sensor."""
@@ -1086,12 +1082,6 @@ def get_platform_attributes(platform: str) -> tuple[WithingsAttribute, ...]:
 class WithingsLocalOAuth2Implementation(AuthImplementation):
     """Oauth2 implementation that only uses the external url."""
 
-    @property
-    def redirect_uri(self) -> str:
-        """Return the redirect uri."""
-        url = get_url(self.hass, allow_internal=False, prefer_cloud=True)
-        return f"{url}{AUTH_CALLBACK_PATH}"
-
     async def _token_request(self, data: dict) -> dict:
         """Make a token request and adapt Withings API reply."""
         new_token = await super()._token_request(data)
